[![Travis](https://img.shields.io/travis/figome/python-festung/master.svg?style=flat-square)](https://travis-ci.org/figome/python-festung)
[![PyPI](https://img.shields.io/pypi/v/festung.svg?style=flat-square)](https://pypi.python.org/pypi/festung)

Festung DBAPI for Python
========================

This library provides a [Database API v2.0](https://www.python.org/dev/peps/pep-0249/) to Festung.
